[aspell]: http://aspell.net/
[fnmatch]: https://facelessuser.github.io/wcmatch/fnmatch
[glob]: https://facelessuser.github.io/wcmatch/glob/
[hunspell]: https://hunspell.github.io/
[soup-sieve]: https://facelessuser.github.io/soupsieve/
[win-unicode-console]: https://github.com/Drekin/win-unicode-console
[wsl]: https://docs.microsoft.com/en-us/windows/wsl/install-win10
